@@ -42,7 +42,7 @@ try:
 except ImportError:
     pass
 
-__version__ = "0.8.0"
+__version__ = "0.9.1"
 __repo__ = "https://github.com/adafruit/Adafruit_CircuitPython_espATcontrol.git"
 
 
@@ -180,7 +180,7 @@ class ESP_ATcontrol:
                 return int(reply[8:])
         raise RuntimeError("Bad response to CIPMUX?")
 
-    def socket_connect(
+    def socket_connect(  # pylint: disable=too-many-branches
         self,
         conntype: str,
         remote: str,
@@ -191,7 +191,31 @@ class ESP_ATcontrol:
     ) -> bool:
         """Open a socket. conntype can be TYPE_TCP, TYPE_UDP, or TYPE_SSL. Remote
         can be an IP address or DNS (we'll do the lookup for you. Remote port
-        is integer port on other side. We can't set the local port"""
+        is integer port on other side. We can't set the local port.
+
+        Note that this method is usually called by the requests-package, which
+        does not know anything about conntype. So it is mandatory to set
+        the conntype manually before calling this method if the conntype-parameter
+        is not provided.
+
+        If requests are done using ESPAT_WiFiManager, the conntype is set there
+        depending on the protocol (http/https)."""
+
+        # if caller does not provide conntype, use default conntype from
+        # object if set, otherwise fall back to old buggy logic
+        if not conntype and self._conntype:
+            conntype = self._conntype
+        elif not conntype:
+            # old buggy code from espatcontrol_socket
+            # added here for compatibility with old code
+            if remote_port == 80:
+                conntype = self.TYPE_TCP
+            elif remote_port == 443:
+                conntype = self.TYPE_SSL
+            # to cater for MQTT over TCP
+            elif remote_port == 1883:
+                conntype = self.TYPE_TCP
+
         # lets just do one connection at a time for now
         if conntype == self.TYPE_UDP:
             # always disconnect for TYPE_UDP
@@ -219,7 +243,7 @@ class ESP_ATcontrol:
         replies = self.at_response(cmd, timeout=10, retries=retries).split(b"\r\n")
         for reply in replies:
             if reply == b"CONNECT" and (
-                conntype == self.TYPE_TCP
+                conntype in (self.TYPE_TCP, self.TYPE_SSL)
                 and self.status == self.STATUS_SOCKETOPEN
                 or conntype == self.TYPE_UDP
             ):
@@ -316,15 +340,14 @@ class ESP_ATcontrol:
                         break  # We've received all the data. Don't wait until timeout.
             else:  # no data waiting
                 self.hw_flow(True)  # start the floooow
-        totalsize = sum([len(x) for x in bundle])
+        totalsize = sum(len(x) for x in bundle)
         ret = bytearray(totalsize)
         i = 0
         for x in bundle:
             for char in x:
                 ret[i] = char
                 i += 1
-        for x in bundle:
-            del x
+        del bundle
         gc.collect()
         return ret
 
@@ -415,6 +438,16 @@ class ESP_ATcontrol:
             raise RuntimeError("Invalid Mode")
         self.at_response("AT+CWMODE=%d" % mode, timeout=3)
 
+    @property
+    def conntype(self) -> Union[str, None]:
+        """The configured connection-type"""
+        return self._conntype
+
+    @conntype.setter
+    def conntype(self, conntype: str) -> None:
+        """set connection-type for subsequent socket_connect()"""
+        self._conntype = conntype
+
     @property
     def local_ip(self) -> Union[str, None]:
         """Our local IP address as a dotted-quad string"""
